@@ -115,6 +115,15 @@ _code_providers = [
         "origin_url_regexp": "^https://gitlab.inria.fr/",
         "origin_types": "repositories",
     },
+    {
+        "provider_id": "ipol",
+        "provider_url": "https://www.ipol.im/",
+        "provider_logo": "img/logos/ipol.png",
+        "provider_info": "software artifacts associated to the articles "
+        "IPOL publishes",
+        "origin_url_regexp": "^https://doi.org/10.5201/ipol",
+        "origin_types": "tarballs",
+    },
     {
         "provider_id": "npm",
         "provider_url": "https://www.npmjs.com/",
@@ -124,6 +133,15 @@ _code_providers = [
         "origin_url_regexp": "^https://www.npmjs.com/",
         "origin_types": "packages",
     },
+    {
+        "provider_id": "nixos",
+        "provider_url": "https://nixos.org/",
+        "provider_logo": "img/logos/nixos.png",
+        "provider_info": "source code tarballs used to build the Nix package "
+        "collection",
+        "origin_url_regexp": "^https://nix-community.github.io/nixpkgs-swh",
+        "origin_types": "tarballs",
+    },
     {
         "provider_id": "pypi",
         "provider_url": "https://pypi.org",
